# eolearn.io subpackage

Input/output subpackage that deals with obtaining data from Sentinel Hub services or saving and loading data locally.

For more information about the module visit [readthedocs](https://eo-learn.readthedocs.io/en/latest/reference/eolearn.io.html), or see the [module task index](https://eo-learn.readthedocs.io/en/latest/eotasks.html#io).
